# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.events_controller import EventsController


class EventsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(EventsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = EventsController(cls.config, cls.response_catcher)

    # Get events, paginated by 100
    #
    def test_getevents_paginatedby_100(self):
        # Parameters for the API call
        country_code = None
        mtype = None
        page = None
        upcoming_events_only = None
        from_date = None
        to_date = None

        # Perform the API call through the SDK function
        self.controller.getevents_paginatedby_100(country_code, mtype, page, upcoming_events_only, from_date, to_date)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Get list of event countries
    #
    def test_getlistofeventcountries(self):

        # Perform the API call through the SDK function
        self.controller.getlistofeventcountries()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Get list of event types
    #
    def test_getlistofeventstypes(self):

        # Perform the API call through the SDK function
        self.controller.getlistofeventstypes()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)




# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.configuration import Server
from coingeckoapiv3.controllers.base_controller import BaseController


class DerivativesController(BaseController):

    """A Controller to access Endpoints in the coingeckoapiv3 API."""

    def __init__(self, config, call_back=None):
        super(DerivativesController, self).__init__(config, call_back)

    def listallderivativetickers(self,
                                 include_tickers=None):
        """Does a GET request to /derivatives.

        List all derivative tickers

        Args:
            include_tickers (string, optional): ['all', 'unexpired'] - expired
                to show unexpired tickers, all to list all tickers, defaults
                to unexpired

        Returns:
            void: Response from the API. List all derivative tickers

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/derivatives'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'include_tickers': include_tickers
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def listallderivativeexchanges(self,
                                   order=None,
                                   per_page=None,
                                   page=None):
        """Does a GET request to /derivatives/exchanges.

        List all derivative exchanges

        Args:
            order (string, optional): order results using following params
                name_asc，name_desc，open_interest_btc_asc，open_interest_btc_desc
                ，trade_volume_24h_btc_asc，trade_volume_24h_btc_desc
            per_page (int, optional): Total results per page
            page (int, optional): Page through results

        Returns:
            void: Response from the API. List all derivative exchanges

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/derivatives/exchanges'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'order': order,
            'per_page': per_page,
            'page': page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def showderivativeexchangedata(self,
                                   id,
                                   include_tickers=None):
        """Does a GET request to /derivatives/exchanges/{id}.

        show derivative exchange data

        Args:
            id (string): pass the exchange id (can be obtained from
                derivatives/exchanges/list) eg. bitmex
            include_tickers (string, optional): ['all', 'unexpired'] - expired
                to show unexpired tickers, all to list all tickers, leave
                blank to omit tickers data in response

        Returns:
            void: Response from the API. show derivative exchange data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/derivatives/exchanges/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'include_tickers': include_tickers
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def listallderivativeexchangesnameandidentifier(self):
        """Does a GET request to /derivatives/exchanges/list.

        List all derivative exchanges name and identifier

        Returns:
            void: Response from the API. List all derivative exchanges name
                and identifier

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/derivatives/exchanges/list'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class APIException(Exception):

    """Class that handles HTTP Exceptions when fetching API Endpoints.

    Attributes:
        response_code (int): The status code of the response.
        response (HttpResponse): The HttpResponse of the API call.

    """

    def __init__(self,
                 reason,
                 response):
        """Constructor for the APIException class

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.
            response (HttpResponse): The HttpResponse of the API call.

        """
        super(APIException, self).__init__(reason)
        self.reason = reason
        self.response = response
        self.response_code = response.status_code



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.configuration import Server
from coingeckoapiv3.controllers.base_controller import BaseController


class SimpleController(BaseController):

    """A Controller to access Endpoints in the coingeckoapiv3 API."""

    def __init__(self, config, call_back=None):
        super(SimpleController, self).__init__(config, call_back)

    def getthecurrentpriceofanycryptocurrenciesinanyothersupportedcurrenciesthatyouneed(self,
                                                                                        ids,
                                                                                        vs_currencies,
                                                                                        include_market_cap=None,
                                                                                        include_24_hr_vol=None,
                                                                                        include_24_hr_change=None,
                                                                                        include_last_updated_at=None):
        """Does a GET request to /simple/price.

        Get the current price of any cryptocurrencies in any other supported
        currencies that you need.

        Args:
            ids (string): id of coins, comma-separated if querying more than 1
                coin *refers to <b>`coins/list`</b>
            vs_currencies (string): vs_currency of coins, comma-separated if
                querying more than 1 vs_currency *refers to
                <b>`simple/supported_vs_currencies`</b>
            include_market_cap (string, optional): <b>true/false</b> to
                include market_cap, <b>default: false</b>
            include_24_hr_vol (string, optional): <b>true/false</b> to include
                24hr_vol, <b>default: false</b>
            include_24_hr_change (string, optional): <b>true/false</b> to
                include 24hr_change, <b>default: false</b>
            include_last_updated_at (string, optional): <b>true/false</b> to
                include last_updated_at of price, <b>default: false</b>

        Returns:
            void: Response from the API. price(s) of cryptocurrency

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/simple/price'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'ids': ids,
            'vs_currencies': vs_currencies,
            'include_market_cap': include_market_cap,
            'include_24hr_vol': include_24_hr_vol,
            'include_24hr_change': include_24_hr_change,
            'include_last_updated_at': include_last_updated_at
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def getcurrentpriceoftokens_usingcontractaddresses_foragivenplatforminanyothercurrencythatyouneed(self,
                                                                                                      id,
                                                                                                      contract_addresses,
                                                                                                      vs_currencies,
                                                                                                      include_market_cap=None,
                                                                                                      include_24_hr_vol=None,
                                                                                                      include_24_hr_change=None,
                                                                                                      include_last_updated_at=None):
        """Does a GET request to /simple/token_price/{id}.

        Get current price of tokens (using contract addresses) for a given
        platform in any other currency that you need.

        Args:
            id (string): The id of the platform issuing tokens (See
                asset_platforms endpoint for list of options)
            contract_addresses (string): The contract address of tokens, comma
                separated
            vs_currencies (string): vs_currency of coins, comma-separated if
                querying more than 1 vs_currency *refers to
                <b>`simple/supported_vs_currencies`</b>
            include_market_cap (string, optional): <b>true/false</b> to
                include market_cap, <b>default: false</b>
            include_24_hr_vol (string, optional): <b>true/false</b> to include
                24hr_vol, <b>default: false</b>
            include_24_hr_change (string, optional): <b>true/false</b> to
                include 24hr_change, <b>default: false</b>
            include_last_updated_at (string, optional): <b>true/false</b> to
                include last_updated_at of price, <b>default: false</b>

        Returns:
            void: Response from the API. price(s) of cryptocurrency

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/simple/token_price/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'contract_addresses': contract_addresses,
            'vs_currencies': vs_currencies,
            'include_market_cap': include_market_cap,
            'include_24hr_vol': include_24_hr_vol,
            'include_24hr_change': include_24_hr_change,
            'include_last_updated_at': include_last_updated_at
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def getlistofsupported_vs_currencies(self):
        """Does a GET request to /simple/supported_vs_currencies.

        Get list of supported_vs_currencies.

        Returns:
            void: Response from the API. list of supported_vs_currencies

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/simple/supported_vs_currencies'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.exchanges_controller import ExchangesController


class ExchangesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(ExchangesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = ExchangesController(cls.config, cls.response_catcher)

    # List all exchanges
    def test_listallexchanges(self):
        # Parameters for the API call
        per_page = None
        page = None

        # Perform the API call through the SDK function
        self.controller.listallexchanges(per_page, page)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Use this to obtain all the markets' id in order to make API calls
    def test_listallsupportedmarketsidandname_nopaginationrequired(self):

        # Perform the API call through the SDK function
        self.controller.listallsupportedmarketsidandname_nopaginationrequired()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)




# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.configuration import Server
from coingeckoapiv3.controllers.base_controller import BaseController


class StatusUpdatesController(BaseController):

    """A Controller to access Endpoints in the coingeckoapiv3 API."""

    def __init__(self, config, call_back=None):
        super(StatusUpdatesController, self).__init__(config, call_back)

    def listallstatus_updateswithdata_description_category_created_at_user_user_titleandpin(self,
                                                                                            category=None,
                                                                                            project_type=None,
                                                                                            per_page=None,
                                                                                            page=None):
        """Does a GET request to /status_updates.

        List all status_updates with data (description, category, created_at,
        user, user_title and pin)

        Args:
            category (string, optional): Filtered by category (eg. general,
                milestone, partnership, exchange_listing, software_release,
                fund_movement, new_listings, event)
            project_type (string, optional): Filtered by Project Type (eg.
                coin, market). If left empty returns both status from coins
                and markets.
            per_page (int, optional): Total results per page
            page (int, optional): Page through results

        Returns:
            void: Response from the API. List all status_updates with data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/status_updates'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'category': category,
            'project_type': project_type,
            'per_page': per_page,
            'page': page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.configuration import Server
from coingeckoapiv3.controllers.base_controller import BaseController


class ContractController(BaseController):

    """A Controller to access Endpoints in the coingeckoapiv3 API."""

    def __init__(self, config, call_back=None):
        super(ContractController, self).__init__(config, call_back)

    def getcoininfofromcontractaddress(self,
                                       id,
                                       contract_address):
        """Does a GET request to /coins/{id}/contract/{contract_address}.

        Get coin info from contract address

        Args:
            id (string): Asset platform (See asset_platforms endpoint for list
                of options)
            contract_address (string): Token's contract address

        Returns:
            void: Response from the API. Get current data for a coin

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/coins/{id}/contract/{contract_address}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True},
            'contract_address': {'value': contract_address, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def gethistoricalmarketdataincludeprice_marketcap_and_24_hvolume_granularityauto_fromacontractaddress(self,
                                                                                                          id,
                                                                                                          contract_address,
                                                                                                          vs_currency,
                                                                                                          days):
        """Does a GET request to /coins/{id}/contract/{contract_address}/market_chart/.

        Get historical market data include price, market cap, and 24h volume
        (granularity auto)

        Args:
            id (string): The id of the platform issuing tokens (See
                asset_platforms endpoint for list of options)
            contract_address (string): Token's contract address
            vs_currency (string): The target currency of market data (usd,
                eur, jpy, etc.)
            days (string): Data up to number of days ago (eg. 1,14,30,max)

        Returns:
            void: Response from the API. Get historical market data include
                price, market cap, and 24h volume

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/coins/{id}/contract/{contract_address}/market_chart/'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True},
            'contract_address': {'value': contract_address, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'vs_currency': vs_currency,
            'days': days
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def gethistoricalmarketdataincludeprice_marketcap_and_24_hvolumewithinarangeoftimestamp_granularityauto_fromacontractaddress(self,
                                                                                                                                 id,
                                                                                                                                 contract_address,
                                                                                                                                 vs_currency,
                                                                                                                                 mfrom,
                                                                                                                                 to):
        """Does a GET request to /coins/{id}/contract/{contract_address}/market_chart/range.

        Get historical market data include price, market cap, and 24h volume
        within a range of timestamp (granularity auto)

        Args:
            id (string): The id of the platform issuing tokens (See
                asset_platforms endpoint for list of options)
            contract_address (string): Token's contract address
            vs_currency (string): The target currency of market data (usd,
                eur, jpy, etc.)
            mfrom (string): From date in UNIX Timestamp (eg. 1392577232)
            to (string): To date in UNIX Timestamp (eg. 1422577232)

        Returns:
            void: Response from the API. Get historical market data include
                price, market cap, and 24h volume

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/coins/{id}/contract/{contract_address}/market_chart/range'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True},
            'contract_address': {'value': contract_address, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'vs_currency': vs_currency,
            'from': mfrom,
            'to': to
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.status_updates_controller import StatusUpdatesController


class StatusUpdatesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(StatusUpdatesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = StatusUpdatesController(cls.config, cls.response_catcher)

    # List all status_updates with data (description, category, created_at, user, user_title and pin)
    #
    def test_listallstatus_updateswithdata_description_category_created_at_user_user_titleandpin(self):
        # Parameters for the API call
        category = None
        project_type = None
        per_page = None
        page = None

        # Perform the API call through the SDK function
        self.controller.listallstatus_updateswithdata_description_category_created_at_user_user_titleandpin(category, project_type, per_page, page)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

